@@ -255,7 +255,8 @@ class SSD1306_I2C(_SSD1306):
                 self.pagebuffer[1:] = self.buffer[
                     1 + self.width * page : 1 + self.width * (page + 1)
                 ]
-                self.i2c_device.write(self.pagebuffer)
+                with self.i2c_device:
+                    self.i2c_device.write(self.pagebuffer)
         else:
             with self.i2c_device:
                 self.i2c_device.write(self.buffer)
@@ -291,7 +292,8 @@ class SSD1306_SPI(_SSD1306):
         phase=0,
         page_addressing=False
     ):
-        if page_addressing:
+        self.page_addressing = page_addressing
+        if self.page_addressing:
             raise NotImplementedError(
                 "Page addressing mode with SPI has not yet been implemented."
             )
